#!/bin/bash
# you could add -x to the above to track the progress of the job
#
SOURCEDIR=/Users/rick/test
FILTER=*.sps
TEMP_DIR=/Users/rick/tmp
OUTPUT_PATH=/Users/rick/results
STATS_PATH="/Applications/IBM SPSS Statistics 28/SPSS Statistics.app/Contents/MacOS"
STATS_EXE=stats
SPJ_TEMPLATE=/Users/rick/test/template.spj
OUTPUT_TYPE="viewer"
#could also be "text-codepage"
TIMEOUT=300
MYPATH=$PWD
#
count=1
#

shopt -s nullglob
filearray=(${SOURCEDIR}/${FILTER})

if [ ! -d "$DIRECTORY" ]; then
	mkdir -p ${OUTPUT_PATH}
fi

for syntax in "${filearray[@]}"
	do
		a="$syntax"
 		xpath=${a%/*}
		xbase=${a##*/}
		xfext=${xbase##*.}
		xpref=${xbase%.*}
		root=${OUTPUT_PATH}/${xpref}
		SPS=${xpath}/${xbase}
		
		if [ ${OUTPUT_TYPE} == "viewer" ] ; then
			OUT=${root}.spv
		else
			OUT=${root}.txt
		fi

		ERRFILE=${root}_errors.txt
		SPJ=${TEMP_DIR}/temp.spj
		
		cat ${SPJ_TEMPLATE} | sed "s#OUTPUT_TYPE_HERE#${OUTPUT_TYPE}#g" | sed "s#OUTFILE_HERE#${OUT}#g" | sed "s#SPS_FILE_HERE#${SPS}#g" > ${SPJ}

		echo $a
		echo "$count: \"$syntax\""
  		echo "Running production facility..."
		cd "${STATS_PATH}"
		./${STATS_EXE} ${SPJ} --production 2>$ERRFILE &
		STATS_PID=$!
		let ICOUNTER=0
	
		while jobs | grep -q "Running" ; do
			sleep 1
			let ICOUNTER=ICOUNTER+1
			if [ $ICOUNTER -eq $TIMEOUT ] ; then
				if [[ "$OSTYPE" == "linux-gnu" ]]; then
					kill -9 $STATS_PID
				elif [[ "$OSTYPE" == "darwin"* ]]; then
					kill $STATS_PID # Mac OSX
				elif [[ "$OSTYPE" == "cygwin" ]]; then
					taskkill /PID $STATS_PID /F # POSIX compatibility layer and Linux environment emulation for Windows
				elif [[ "$OSTYPE" == "msys" ]]; then
					taskkill /PID $STATS_PID /F  # Lightweight shell and GNU utilities compiled for Windows (part of MinGW)
				elif [[ "$OSTYPE" == "win32" ]]; then
					taskkill /PID $STATS_PID /F  # I'm not sure this can happen.
				elif [[ "$OSTYPE" == "freebsd"* ]]; then
					kill -9 $STATS_PID ;
			else
				kill -9 $STATS_PID ; # Unknown.
			fi
		fi
		done
		if [ ! -s $ERRFILE ] ; then
			rm $ERRFILE
		fi
	cd ${MYPATH}
  	count=$((count+1))
done
rm ${SPJ}